PtcRunner.SubAgent.Signature.Parser (PtcRunner v0.9.0)

Copy Markdown View Source

NimbleParsec-based parser for signature strings.

Transforms signature syntax into AST:

  • Primitives: :string, :int, :float, :bool, :keyword, :any
  • Collections: [:type], {field :type}, :map
  • Optional fields: :type?
  • Full format: (params) -> output or shorthand: output

Summary

Functions

Parse a signature string into AST.

Parses the given binary as parse_impl.

Functions

parse(input)

@spec parse(String.t()) :: {:ok, term()} | {:error, String.t()}

Parse a signature string into AST.

Returns {:ok, ast} or {:error, reason}

parse_impl(binary, opts \\ [])

@spec parse_impl(binary(), keyword()) ::
  {:ok, [term()], rest, context, line, byte_offset}
  | {:error, reason, rest, context, line, byte_offset}
when line: {pos_integer(), byte_offset},
     byte_offset: non_neg_integer(),
     rest: binary(),
     reason: String.t(),
     context: map()

Parses the given binary as parse_impl.

Returns {:ok, [token], rest, context, position, byte_offset} or {:error, reason, rest, context, line, byte_offset} where position describes the location of the parse_impl (start position) as {line, offset_to_start_of_line}.

To column where the error occurred can be inferred from byte_offset - offset_to_start_of_line.

Options

  • :byte_offset - the byte offset for the whole binary, defaults to 0
  • :line - the line and the byte offset into that line, defaults to {1, byte_offset}
  • :context - the initial context value. It will be converted to a map