Simulated Java interop for PTC-Lisp.
Summary
Functions
Simulates System/currentTimeMillis.
Simulates .getTime method on java.util.Date.
Simulates .indexOf method on strings. Returns the grapheme index of the first occurrence of substring, or -1 if not found.
Simulates .indexOf method on strings with a starting position.
Delegates to Runtime.String.index_of/3 and converts nil to -1.
Simulates .lastIndexOf method on strings.
Delegates to Runtime.String.last_index_of/2 and converts nil to -1.
Constructs a java.util.Date. If no args, returns now. If one arg (number or string), returns date accordingly.
Simulates java.time.LocalDate/parse. Only supports ISO-8601 YYYY-MM-DD.
Functions
Simulates System/currentTimeMillis.
Simulates .getTime method on java.util.Date.
Simulates .indexOf method on strings. Returns the grapheme index of the first occurrence of substring, or -1 if not found.
Delegates to Runtime.String.index_of/2 and converts nil to -1 for Java semantics.
Uses grapheme indices (not byte offsets) for compatibility with subs and other
PTC-Lisp string functions.
Simulates .indexOf method on strings with a starting position.
Delegates to Runtime.String.index_of/3 and converts nil to -1.
Simulates .lastIndexOf method on strings.
Delegates to Runtime.String.last_index_of/2 and converts nil to -1.
Constructs a java.util.Date. If no args, returns now. If one arg (number or string), returns date accordingly.
Simulates java.time.LocalDate/parse. Only supports ISO-8601 YYYY-MM-DD.